==> tax-device-contract-model-1.1-20190715.112923-33-sources.jar: com/xforceplus/micro/tax/device/contract/model/ClientUpdateResponse.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.micro.tax.device.contract.model.ResponseHead;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * ClientUpdateResponse
 */

@JsonInclude(NON_NULL)
public class ClientUpdateResponse implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("head")
  private ResponseHead head = null;

  @JsonProperty("url")
  private String url = null;

  @JsonIgnore
  public ClientUpdateResponse head(ResponseHead head) {
    this.head = head;
    return this;
  }

   /**
   * 公共头部响应
   * @return head
  **/

  @Valid

  @ApiModelProperty(value = "公共头部响应")
  public ResponseHead getHead() {
    return head;
  }

  public void setHead(ResponseHead head) {
    this.head = head;
  }

  @JsonIgnore
  public ClientUpdateResponse url(String url) {
    this.url = url;
    return this;
  }

   /**
   * 下载链接
   * @return url
  **/


  @ApiModelProperty(value = "下载链接")
  public String getUrl() {
    return url;
  }

  public void setUrl(String url) {
    this.url = url;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ClientUpdateResponse clientUpdateResponse = (ClientUpdateResponse) o;
    return Objects.equals(this.head, clientUpdateResponse.head) &&
        Objects.equals(this.url, clientUpdateResponse.url);
  }

  @Override
  public int hashCode() {
    return Objects.hash(head, url);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class ClientUpdateResponse {\n");
    
    sb.append("    head: ").append(toIndentedString(head)).append("\n");
    sb.append("    url: ").append(toIndentedString(url)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> tax-device-contract-model-1.7-20240613.095407-45-sources.jar: com/xforceplus/micro/tax/device/contract/model/ClientUpdateResponse.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.xforceplus.micro.tax.device.contract.model.ResponseHead;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * ClientUpdateResponse
 */

@JsonInclude(NON_NULL)
public class ClientUpdateResponse implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("head")
  private ResponseHead head = null;

  @JsonProperty("url")
  private String url = null;

  @JsonProperty("tcUrl")
  private String tcUrl = null;

  @JsonIgnore
  public ClientUpdateResponse head(ResponseHead head) {
    this.head = head;
    return this;
  }

   /**
   * 公共头部响应
   * @return head
  **/

  @Valid

  @ApiModelProperty(value = "公共头部响应")
  public ResponseHead getHead() {
    return head;
  }

  public void setHead(ResponseHead head) {
    this.head = head;
  }

  @JsonIgnore
  public ClientUpdateResponse url(String url) {
    this.url = url;
    return this;
  }

   /**
   * 阿里云下载链接
   * @return url
  **/


  @ApiModelProperty(value = "阿里云下载链接")
  public String getUrl() {
    return url;
  }

  public void setUrl(String url) {
    this.url = url;
  }

  @JsonIgnore
  public ClientUpdateResponse tcUrl(String tcUrl) {
    this.tcUrl = tcUrl;
    return this;
  }

   /**
   * 腾讯云下载链接
   * @return tcUrl
  **/


  @ApiModelProperty(value = "腾讯云下载链接")
  public String getTcUrl() {
    return tcUrl;
  }

  public void setTcUrl(String tcUrl) {
    this.tcUrl = tcUrl;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ClientUpdateResponse clientUpdateResponse = (ClientUpdateResponse) o;
    return Objects.equals(this.head, clientUpdateResponse.head) &&
        Objects.equals(this.url, clientUpdateResponse.url) &&
        Objects.equals(this.tcUrl, clientUpdateResponse.tcUrl);
  }

  @Override
  public int hashCode() {
    return Objects.hash(head, url, tcUrl);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class ClientUpdateResponse {\n");
    
    sb.append("    head: ").append(toIndentedString(head)).append("\n");
    sb.append("    url: ").append(toIndentedString(url)).append("\n");
    sb.append("    tcUrl: ").append(toIndentedString(tcUrl)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
